@@ -1,4 +1,4 @@
-# This file is part of GridCal.g
+# This file is part of GridCal.
 #
 # GridCal is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,42 +12,29 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with GridCal.  If not, see <http://www.gnu.org/licenses/>.
-print('Loading GridCal...')
 import os
 import sys
-import matplotlib
-# matplotlib.use('Qt5Agg')
+import ctypes
+
 PACKAGE_PARENT = '..'
 SCRIPT_DIR = os.path.dirname(os.path.realpath(os.path.join(os.getcwd(), os.path.expanduser(__file__))))
 sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
 from GridCal.__version__ import about_msg
-from GridCal.Gui.Main.GridCalMain import run
-from GridCal.Gui.Main.banner import Ui_splashScreen, QMainWindow, Qt, QApplication
-
-
-class Splash(QMainWindow):
-
-    def __init__(self, parent=None):
-        """
-
-        @param parent:
-        """
-
-        # create main window
-        QMainWindow.__init__(self, parent)
-        self.ui = Ui_splashScreen()
-        self.ui.setupUi(self)
-        self.setWindowFlags(Qt.SplashScreen | Qt.FramelessWindowHint)
+from GridCal.Gui.Main.GridCalMain import runGridCal
+import platform
 
+if platform.system() == 'Windows':
+    # this makes the icon display properly under windows
+    myappid = 'mycompany.myproduct.subproduct.version'  # arbitrary string
+    ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(myappid)
 
 if __name__ == "__main__":
+    print('Loading GridCal...')
     print(about_msg)
 
-    # app = QApplication(sys.argv)
-    # app.setStyle('Fusion')  # ['Breeze', 'Oxygen', 'QtCurve', 'Windows', 'Fusion']
-    #
-    # splash = Splash()
-    # splash.show()
+    # Set the application style to the clear theme
+    os.environ["QT_QUICK_CONTROLS_STYLE"] = "Basic"
+    # os.environ["QT_QPA_PLATFORMTHEME"] = "qt5ct"  # this forces QT-only menus and look and feel
+
+    runGridCal()
 
-    run(use_native_dialogues=False)
-    # sys.exit(app.exec_())
