@@ -1,5 +1,5 @@
 # GridCal
-# Copyright (C) 2022 Santiago Peñate Vera
+# Copyright (C) 2015 - 2024 Santiago Peñate Vera
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -17,9 +17,9 @@
 
 import sys
 
-from PySide2 import QtWidgets
+from PySide6 import QtWidgets
 
-from GridCal.Gui.Main.ConsoleLog import *
+from GridCal.Gui.Main.ConsoleLog import Ui_mainWindow
 
 
 class ConsoleLogDialogue(QtWidgets.QMainWindow):
