@@ -1,9 +1,9 @@
 import sys
 import openpyxl
 
-from PySide2 import QtCore, QtGui, QtWidgets
+from PySide6 import QtCore, QtGui, QtWidgets
 
-from GridCal.Gui.ProfilesInput.excel_sheet_selection import *
+from GridCal.Gui.ProfilesInput.excel_sheet_selection import Ui_ExcelSelectionDialog
 
 
 class ExcelDialog(QtWidgets.QDialog):
