@@ -1,21 +1,36 @@
-import os
-import string
+# GridCal
+# Copyright (C) 2015 - 2024 Santiago Peñate Vera
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 3 of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program; if not, write to the Free Software Foundation,
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 import sys
-from random import randint
-from enum import Enum
 import numpy as np
-import pandas as pd
-from PySide2.QtWidgets import *
+from PySide6 import QtWidgets
 
-from GridCal.Gui.SigmaAnalysis.gui import *
-from GridCal.Gui.Session.results_model import ResultsModel
-from GridCal.Engine.Simulations.result_types import ResultTypes
-from GridCal.Engine.Simulations.SigmaAnalysis.sigma_analysis_driver import SigmaAnalysisResults
+from GridCal.Gui.SigmaAnalysis.gui import Ui_MainWindow
+from GridCal.Session.results_model import ResultsModel
+from GridCalEngine.enumerations import ResultTypes
+from GridCalEngine.Simulations.SigmaAnalysis.sigma_analysis_driver import SigmaAnalysisResults
 
 
 class SigmaAnalysisGUI(QtWidgets.QMainWindow):
+    """
+    SigmaAnalysisGUI
+    """
 
-    def __init__(self, parent=None, results: SigmaAnalysisResults = None, bus_names=None, use_native_dialogues=True):
+    def __init__(self, parent=None, results: SigmaAnalysisResults = None, bus_names=None,
+                 good_coefficients=True):
         """
 
         :param parent:
@@ -26,8 +41,6 @@ class SigmaAnalysisGUI(QtWidgets.QMainWindow):
         self.ui.setupUi(self)
         self.setWindowTitle('HELM-Sigma analysis dialogue')
 
-        self.use_native_dialogues = use_native_dialogues
-
         self.results = results
 
         if results is not None:
@@ -54,13 +67,13 @@ class SigmaAnalysisGUI(QtWidgets.QMainWindow):
         :param text: Text to display
         :param title: Name of the window
         """
-        msg = QMessageBox()
-        msg.setIcon(QMessageBox.Information)
+        msg = QtWidgets.QMessageBox()
+        msg.setIcon(QtWidgets.QMessageBox.Icon.Information)
         msg.setText(text)
         # msg.setInformativeText("This is additional information")
         msg.setWindowTitle(title)
         # msg.setDetailedText("The details are as follows:")
-        msg.setStandardButtons(QMessageBox.Ok)
+        msg.setStandardButtons(QtWidgets.QMessageBox.StandardButton.Ok)
         retval = msg.exec_()
 
     def copy_to_clipboard(self):
@@ -76,35 +89,27 @@ class SigmaAnalysisGUI(QtWidgets.QMainWindow):
         :return:
         """
         if self.mdl is not None:
-            options = QFileDialog.Options()
-            if self.use_native_dialogues:
-                options |= QFileDialog.DontUseNativeDialog
-
-            file, filter = QFileDialog.getSaveFileName(self, "Export results", '',
-                                                       filter="CSV (*.csv);;Excel files (*.xlsx)",
-                                                       options=options)
+            file, filter = QtWidgets.QFileDialog.getSaveFileName(self, "Export results", '',
+                                                                 filter="CSV (*.csv);;Excel files (*.xlsx)")
 
             if file != '':
                 if 'xlsx' in filter:
                     f = file
                     if not f.endswith('.xlsx'):
                         f += '.xlsx'
-                    self.mdl.save_to_excel(f, mode='real')
+                    self.mdl.save_to_excel(f)
                     print('Saved!')
                 if 'csv' in filter:
                     f = file
                     if not f.endswith('.csv'):
                         f += '.csv'
-                    self.mdl.save_to_csv(f, mode='real')
+                    self.mdl.save_to_csv(f)
                     print('Saved!')
 
 
-
 if __name__ == "__main__":
-
     app = QtWidgets.QApplication(sys.argv)
     window = SigmaAnalysisGUI()
     window.resize(1.61 * 700.0, 600.0)  # golden ratio
     window.show()
     sys.exit(app.exec_())
-
