@@ -1,13 +1,15 @@
 
 import sys
-from PySide2.QtWidgets import *
-from PySide2.QtCore import Qt
-from GridCal.Gui.SyncDialogue.gui import *
-from GridCal.Gui.Session.synchronization_driver import get_issues_tree_view_model, FileSyncThread
+from PySide6 import QtWidgets
+from PySide6.QtCore import Qt
+from GridCal.Gui.SyncDialogue.gui import Ui_Dialog
+from GridCal.Session.synchronization_driver import get_issues_tree_view_model, FileSyncThread
 
 
 class SyncDialogueWindow(QtWidgets.QDialog):
-
+    """
+    SyncDialogueWindow
+    """
     def __init__(self, file_sync_thread: FileSyncThread, parent=None):
         """
 
@@ -36,13 +38,13 @@ class SyncDialogueWindow(QtWidgets.QDialog):
         :param text: Text to display
         :param title: Name of the window
         """
-        msg = QMessageBox()
-        msg.setIcon(QMessageBox.Information)
+        msg = QtWidgets.QMessageBox()
+        msg.setIcon(QtWidgets.QMessageBox.Icon.Information)
         msg.setText(text)
         # msg.setInformativeText("This is additional information")
         msg.setWindowTitle(title)
         # msg.setDetailedText("The details are as follows:")
-        msg.setStandardButtons(QMessageBox.Ok)
+        msg.setStandardButtons(QtWidgets.QMessageBox.StandardButton.Ok)
         retval = msg.exec_()
 
     def closeEvent(self, event):
@@ -105,13 +107,3 @@ class SyncDialogueWindow(QtWidgets.QDialog):
 
         self.file_sync_thread.process_issues()
         self.close()
-
-
-if __name__ == "__main__":
-
-    app = QtWidgets.QApplication(sys.argv)
-    window = SyncDialogueWindow()
-    window.resize(1.61 * 500.0, 500.0)  # golden ratio
-    window.show()
-    sys.exit(app.exec_())
-
