@@ -1,6 +1,22 @@
+# This file is part of GridCal.g
+#
+# GridCal is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# GridCal is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with GridCal.  If not, see <http://www.gnu.org/licenses/>.
+
 import subprocess
 import sys
-import pkg_resources
+# import pkg_resources
+import packaging.version as pkg
 from GridCal.__version__ import __GridCal_VERSION__
 
 
@@ -18,9 +34,10 @@ def find_latest_version(name='GridCal'):
     return latest_version
 
 
-def check_version():
+def check_version(name='GridCal'):
     """
     Check package version
+    :param name: package name, GridCal by default
     :return: version status code, pipy version string
 
     version status code:
@@ -30,10 +47,12 @@ def check_version():
     +1: we are behind pipy, we can update
     """
 
-    latest_version = find_latest_version()
+    latest_version = find_latest_version(name=name)
 
-    pipy_version = pkg_resources.parse_version(latest_version)
-    gc_version = pkg_resources.parse_version(__GridCal_VERSION__)
+    # pipy_version = pkg_resources.parse_version(latest_version)
+    # gc_version = pkg_resources.parse_version(__GridCal_VERSION__)
+    pipy_version = pkg.parse(latest_version)
+    gc_version = pkg.parse(__GridCal_VERSION__)
 
     if pipy_version is None:
         # could not connect
